close all
%% INFORMATION
% This script calculates expected value and standard deviation of wave
% runup and wave rundown based on wave distributions.  
% Results can be found in the variable "Results", where the matrixes are
% ordered so that each row represent one bottom slope in the vector md, 
% and each column represent one equation

%% PARAMETERS

% Input
g=9.81;                         %Acceleration of gravity
Hs=3;                           %Significant wave height
nd=10;                          %number of distributions
neq=11;                         %number of equations for R2
nm=7;                           %number of bottom slopes
hs_shift = 3.25;                % shifting point combined distribution
md = [1/5 1/7 1/10 1/15 ... 
    1/20 1/30 1/50];            % bottom slopes
marginal = ...
    [1 2 3 3 3 3 3 4 4 4];      % type of distribution 
                                % 1:MGAU05 2:OHG16 3:BGGS07 4:MBG90
c_hat = [1 1 1.28 1.28 1.28 ...
    1.28 1.28 1.28 1.28 1.28];  % coefficient: 1 for T=Tp, 1.28 for T=Tz

% Declaration
ER2=zeros(length(md),neq);      % expected value of R2
STDR2=zeros(length(md),neq);    % standard deviation of R2
EHS = zeros(1,nd);              % Expected value of Hs
ER_up=zeros(nm,neq-2);          % expected value runup
STD_up=zeros(nm,neq-2);         % standard deviation runup
ER_down=zeros(nm,2);            % expected value rudown
STD_down=zeros(nm,2);           % standard deviation rundown
Results = struct([]);           % structure for results
ResTab = zeros(neq,nm*2);       % matrix for storing results

% Colours for plot
colours = [
    0            0        0;    % black
    0.402    0.402    0.402;    % grey
    0            0        0;    % black
    0.402    0.402    0.402;    % grey
    1.000        0    0.500;    % pink
    0        0.447    0.741;    % blue
    1.000    0.500        0;    % orange
    0.494    0.184    0.556;    % purple
    0.466    0.674    0.188;    % green
    0.301    0.745    0.933;    % light blue
    0.635    0.078    0.184];   % red

% Strings for plots and saving results
model = {'Bl1', 'Bl2', 'Bld','Sc', 'Pe', 'Ho', 'Vo', 'At1', 'At2','Po1','Po2'};
markers = {'-','-','--','--','-','-','-','-','-','-','-'};
distr = {'MGAU05','NORA10', 'BGGS07_1', 'BGGS07_2','BGGS07_3'...
    ,'BGGS07_4', 'BGGS07_5','MBG90_1','MBG90_2','MBG90_3'};
distr_name = {'MGAU05','NORA10', 'BGGS07 (1)', 'BGGS07 (2)','BGGS07 (3)'...
    ,'BGGS07 (4)', 'BGGS07 (5)','MBG90 (1)','MBG90 (2)','MBG90 (3)'};

%% Parameters distributions

% Parameters for conditional distribution of Hs and T
a1=[1.780 0.74 1.350 1.365 0.790 0.835 1.952 1.240 1.090 0.933];
a2=[0.288 1.20 0.366 0.375 0.805 1.139 0.168 0.337 0.479 0.578];
a3=[0.474 0.21 0.392 0.453 0.292 0.119 0.499 0.538 0.417 0.395];
b1=[0.001 0.001 0.020 0.033 0.055 0.140 0.070 0.0728 0.0407 0.0550];
b2=[0.097 0.113 0.165 0.285 0.195 0.030 0.066 0.383 0.221 0.336];
b3=[-0.255 -0.275 -0.166 -0.752 -0.269 -0.958 -0.081 -0.665 -0.289 -0.585];

%Parameters for marginal distirbution of Hs
s = [0.801 1.690 3.104 2.848 2.939 2.857 2.420 1.410 1.910 1.500];
r = [1.531 1.160 1.357 1.419 1.240 1.449 1.169 1.120 1.270 1.150];
t = [2.713 0.760 0.906 1.021 0.896 0.838 1.258 0.987 0.532 0.679];
k = [0.371^0.5 0 0 0 0 0 0 0 0 0];


%% CALCULATIONS
for i = 1:nd    %distributions
    mnd=1;
    for mn = 1:nm   %bottom slope
        %% Parameters equations
        m = md(mn);
        K=4*m^(0.3);
        
        %Parameters for general equation 1
        a=[0 0.39 -0.21 0 0 0.2 0.58*m 0 0.16];
        b=[1.165 0.795 0.44 0.1 K 0.83 0.53 0.99 0.92];
        c=[0.77 1 1 2.21 1 1 1 1 1];
        d=[0 0 0 0 0 0 0.45 0 0];
        
        %Parameters for general equation 2
        C = [0 0 0 0 0 0 0 0 0 0.49/1.28 0.33];
        
        
        %% Statistical values
        
        for j = 1:neq   %equations
            meanT = a1(i)+a2(i)*Hs^a3(i);
            if marginal(i) == 1 || marginal(i) == 2
                varT = b1(i)+b2(i)*exp(b3(i)*Hs);
            elseif marginal(i) == 3
                varT = (b1(i)+b2(i)*Hs^(b3(i)))^2;
            elseif marginal(i) == 4
                varT = (b1(i)+b2(i)*exp(b3(i)*Hs))^2;
            end
            if j <= neq-2 %General equation 1
                meanR = c(j)*meanT+log(b(j)*m^(c(j))*c_hat(i)^(c(j))...
                    *(g/(2*pi))^(c(j)/2)*Hs^(1-c(j)/2));
                varR = c(j)^2*varT;
                ER = exp(meanR+0.5*varR);
                STDR = ((exp(varR)-1)*exp(2*meanR+varR))^0.5;
                ER2(mn,j) = ER + a(j)*Hs+d(j);
                STDR2(mn,j) = STDR;
            elseif j > neq-2 %General equation 2
                meanR = meanT +log(C(j)*m^.5*c_hat(i)*Hs);
                varR = varT;
                ER2(mn,j) = exp(meanR+0.5*varR);
                STDR2(mn,j) = ((exp(varR)-1)*exp(2*meanR+varR))^0.5;
            end
        end
        
        ResTab(:,mnd) = ER2(mn,:);
        ResTab(:,mnd+1) = STDR2(mn,:);
        mnd = mnd+2;
        
    end
    
    %CHANGING SIGN ON RUNDOWN
    ER2(:,3) = ER2(:,3)*(-1);
    ER2(:,4) = ER2(:,4)*(-1);
    kd=1;
    for k = 1:nm
        ResTab(3,kd)=ResTab(3,kd)*(-1);
        ResTab(4,kd)=ResTab(4,kd)*(-1);
        kd=kd+2;
    end
    
    %% EXPECTED VALUE OF HS
    if marginal(i) == 1
        EHS(i) = exp(s(i)+0.5*k(i)^2)*normcdf((log(hs_shift)-(s(i)...
            +k(i)^2))/k(i))+ t(i)*gammainc(1+1/r(i),(hs_shift/t(i))^r(i));
    else
        EHS(i) = t(i) + s(i)*gamma(1+1/r(i));
    end
    
    %% OTHER CALCULATIONS
    
    % VECTORS WITH RUNUP ONLY
    ER_up(:,1:2)=ER2(:,1:2);
    STD_up(:,1:2)=STDR2(:,1:2);
    ER_up(:,3:9)=ER2(:,5:11);
    STD_up(:,3:9)=STDR2(:,5:11);
    
    % VECTORS WITH RUNDOWN ONLY
    ER_down(:,1:2)=ER2(:,3:4);
    STD_down(:,1:2)=STDR2(:,3:4);
    
    %CALCULATING ERRORBARS
    error_min = zeros(nm,neq-2);
    for mn = 1:nm
        for eq = 1:neq-2
            if ER_up(mn,eq) < STD_up(mn,eq)
                error_min(mn,eq) = ER_up(mn,eq);
            else
                error_min(mn,eq) = STD_up(mn,eq);
            end
        end
    end
    
    %% SAVING RESULTS
    
    % Saving results in struct
    Results(i).Distribution = distr_name(i);
    Results(i).ExpectedValues = ER2;
    Results(i).StandardDeviation = STDR2;
    Results(i).ExpValueRunup = ER_up;
    Results(i).StdRunup = STD_up;
    Results(i).MinRunup = error_min;
    Results(i).ExpValueRundown = ER_down;
    Results(i).StdRundown = STD_down;
    Results(i).MinRundown = STD_down;
    
end
