close all
%% INFORMATION
% This script calculates expected value and standard deviation of wave
% runup and wave rundown based on wind distributions.
% Results can be found in the variable "Results", where the matrixes are
% ordered so that each row represent one bottom slope in the vector md, 
% and each column represent one equation

%% PARAMETERS

% Input
alpha_hat=0.0081;               % Phillips constant
g=9.81;                         % Acceleration of gravity
neq = 11;                       % number of equations
nm=7;                           % number of slopes in calculation
nd = 4;                         % number of distributions
md = [1/5 1/7 1/10 1/15 ...
    1/20 1/30 1/50];            % bottom slopes

% Declarations
Results = struct([]);           % Structure for saving results
ER2=zeros(nm,neq);              % expected value of R2
VarR2=zeros(nm,neq);            % variance of R2
ER2det=zeros(nm,neq);           % deterministic expected value of R2

% Colours for plot
colours = [
    0            0        0;    % black
    0.402    0.402    0.402;    % grey
    0            0        0;    % black
    0.402    0.402    0.402;    % grey
    1.000        0    0.500;    % pink
    0        0.447    0.741;    % blue
    1.000    0.500        0;    % orange
    0.494    0.184    0.556;    % purple
    0.466    0.674    0.188;    % green
    0.301    0.745    0.933;    % light blue
    0.635    0.078    0.184];   % red

% Strings for plots and saving results
markers = {'-','-','--','--','-','-','-','-','-','-','-'};
distr = {'JMH02','MR15_1040','MR15_2060','BG15'};
distr_name = {'JMH02','MR15 (1)','MR15 (2)','BG15'};

%% CALCULATIONS
for i = 1:nd
    % Parameters distributions
    if i == 1       % JMH01
        alpha=1.708;
        beta=8.426;
    elseif i ==2    % MR15 (1)
        alpha=2.30;
        beta=7.11;
    elseif i ==3    % MR15 (2)
        alpha=2.46;
        beta=10.99;
    else            % BG15
        hs=3;
        alpha=1.250+5.600*hs^(.660);
        beta=0.050+5.514*hs^(.280);
    end
    
    
    %% Moments of the distributions
    W=zeros(1,6);
    for mo=1:6
        W(mo)= beta^mo * gamma(1+mo/alpha);
    end
    
    %% Statistical values
    
    for mn = 1:nm
        m = md(mn);
        K=4*m^(0.3);
        
        % General equation 1
        a=[0 0.39 -0.21 0 0 0.2 0.58*m 0 0.16];
        b=[1.165 0.795 0.44 0.1 K 0.83 0.53 0.99 0.92];
        c=[0.77 1 1 2.21 1 1 1 1 1];
        d=[0 0 0 0 0 0 0.45 0 0];
        for eq = 1:(neq-2)
            C = a(eq)*2*sqrt(alpha_hat)/g + b(eq)*m^(c(eq))*...
                (2*pi/g)^(c(eq)/2)*(2*sqrt(alpha_hat)/g)^(1-c(eq)/2);
            ER2(mn,eq) = C*W(2)+d(eq);
            VarR2(mn,eq) = C^2*(W(4)-(W(2))^2);
            ER2det(mn,eq) = C*(W(1))^2+d(eq);
        end
        
        % General equation 2
        C1 = 0.49*m^(.5)*2*pi*sqrt(2*alpha_hat)/(g^2);
        C2 = 0.33*m^(.5)*4*pi*sqrt(alpha_hat)/(g^2);
        ER2(mn,10)  = C1*W(3);
        ER2(mn,11) = C2*W(3);
        VarR2(mn,10)  = C1^2*(W(6)-(W(3))^2);
        VarR2(mn,11) = C2^2*(W(6)-(W(3))^2);
        ER2det(mn,10)  = C1*(W(1))^3;
        ER2det(mn,11) = C2*(W(1))^3;
        
    end
    
    StdR2=sqrt(VarR2);
    
    %% Other calculations
    
    % EXPECTED MEAN WIND AND SIGNIFICANT WAVE HEIGHT
    EU10 = W(1);                            % Expected mean wind speed
    EHS=2*sqrt(alpha_hat)/g*EU10^2;         % Expected significant wave heigth
    xiPd=pi^.5/alpha_hat^(1/4)*EU10;
    xiP=md.*xiPd;                           % Surf parameter
    
    % DIMENSIONLESS RUNUP
    ER2D= ER2/EHS;                          % divided by Hs
    ER2DD(1,:) = ER2(1,:)./xiP(1);          % divided by surf parameter
    ER2DD(2,:) = ER2(2,:)./xiP(2);          % divided by surf parameter
    ER2DD(3,:) = ER2(3,:)./xiP(3);          % divided by surf parameter
    ER2DD(4,:) = ER2(4,:)./xiP(4);          % divided by surf parameter
    ER2DD(5,:) = ER2(5,:)./xiP(5);          % divided by surf parameter
    
    % RATIO BETWEEN DET. AND STOCH. METHOD
    ER2comp=ER2det./ER2;
    
    % VECTORS WITH RUNUP ONLY
    ER_up=zeros(nm,neq-2);
    STD_up=zeros(nm,neq-2);
    ER_up(:,1:2)=ER2(:,1:2);
    STD_up(:,1:2)=StdR2(:,1:2);
    ER_up(:,3:9)=ER2(:,5:11);
    STD_up(:,3:9)=StdR2(:,5:11);
    
    %CALCULATING ERRORBAR
    error_min = zeros(nm,neq-2);
    for mn = 1:nm
        for eq = 1:neq-2
            if ER_up(mn,eq) < STD_up(mn,eq)
                error_min(mn,eq) = ER_up(mn,eq);
            else
                error_min(mn,eq) = STD_up(mn,eq);
            end
        end
    end
    
    % CREATING FILE FOR TABLES
    ResTab = zeros(neq,8);
    mnd=1;
    for mn = [1 3 5 7]
        ResTab(:,mnd) = ER2(mn,:);
        ResTab(:,mnd+1) = StdR2(mn,:);
        mnd = mnd+2;
    end
    
    %CHANGING SIGN ON RUNDOWN
    ER2(:,3) = ER2(:,3)*(-1);
    ER2(:,4) = ER2(:,4)*(-1);
    kd=1;
    for k = 1:4
        ResTab(3,kd)=ResTab(3,kd)*(-1);
        ResTab(4,kd)=ResTab(4,kd)*(-1);
        kd=kd+2;
    end
    
    % VECTORS WITH RUNDOWN ONLY
    ER_down=zeros(nm,2);
    STD_down=zeros(nm,2);
    ER_down(:,1:2)=ER2(:,3:4);
    STD_down(:,1:2)=StdR2(:,3:4);
    
    %% SAVING RESULTS
    Results(i).Distributions = distr_name(i);
    Results(i).ExpU10 = EU10;
    Results(i).ExpHs = EHS;
    Results(i).SurfParameter = xiP.';
    Results(i).ExpectedValue=ER2;
    Results(i).StandardDeviation=StdR2;
    Results(i).ExpRunup = ER_up;
    Results(i).StdRunup = STD_up;
    Results(i).MinRunup = error_min;
    Results(i).ExpRundown = ER_down;
    Results(i).StdRundown = STD_down;
    Results(i).MinRundown = STD_down;
    
end
